plink – A Python/Tk link editor — PLink documentation

# plink – A Python/Tk link editor

Technical documentation of the Python objects that underly PLink. Of interest only to Marc, Nathan, or similar folks.

class `plink.` `LinkEditor`(root=None, no_arcs=False, callback=None, cb_menu='', manifold=None, file_name=None, title='PLink Editor')

  A graphical link drawing tool based on the one embedded in Jeff Weeks’ original SnapPea program.

  `about`()
  `active_crossing_data`()

    Return the tuple of edges crossed by the in and out arrows of the active vertex.

  `alert`()
  `attach_cursor`(reason='')
  `build_menus`()
  `build_plink_menus`()
  `clear`()
  `clear_text`()
  `clicked_on_arrow`(vertex)
  `crossed_arrows`(arrow, ignore_list=[])

    Return a tuple containing the arrows of the diagram which are crossed by the given arrow, in order along the given arrow.

  `cursor_on_arrow`(point)
  `destroy_arrow`(arrow)
  `detach_cursor`(reason='')
  `do_callback`()
  `done`(event=None)
  `double_click`(event)

    Event handler for mouse double-clicks.

  `end_dragging_state`()
  `focus_in`(event)
  `focus_out`(event)
  `full_redraw`()

    Recolors and redraws all components, in DT order, and displays the legend linking colors to cusp indices.

  `generic_arrow`(arrow)
  `generic_vertex`(vertex)
  `goto_drawing_state`(x1, y1)
  `goto_start_state`()
  `hide_DT`()
  `howto`()
  `key_press`(event)

    Handler for keypress events.

  `key_release`(event)

    Handler for keyrelease events.

  `load`(file_name=None)
  `make_alternating`()

    Changes crossings to make the projection alternating. Requires that all components be closed.

  `mouse_moved`(event)

    Handler for mouse motion events.

  `move_active`(x, y)
  `move_is_ok`()
  `not_done`()
  `notice_focus`()
  `reflect`()
  `reopen`()
  `save`()
  `save_image`(file_type='eps', colormode='color')
  `set_info`()
  `set_start_cursor`(x, y)
  `set_view_mode`()
  `shift_click`(event)

    Event handler for mouse shift-clicks.

  `show_DT`()

    Display the DT hit counters next to each crossing. Crossings that need to be flipped for the planar embedding have an asterisk.

  `single_click`(event)

    Event handler for mouse clicks.

  `unpickle`(vertices, arrows, crossings, hot=None)
  `update_crossings`(this_arrow)

    Redraw any arrows which were changed by moving this_arrow.

  `update_info`()
  `update_smooth`()
  `verify_drag`()
  `warn_arcs`()
  `write_text`(string)
  `zoom_in`()
  `zoom_out`()
  `zoom_to_fit`()